# WorkV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV30Rc2**](CreatedDateV30Rc2.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV30Rc2**](LastModifiedDateV30Rc2.md) |  | [optional] 
**source** | [**SourceV30Rc2**](SourceV30Rc2.md) |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 
**title** | [**WorkTitleV30Rc2**](WorkTitleV30Rc2.md) |  | [optional] 
**journal_title** | [**TitleV30Rc2**](TitleV30Rc2.md) |  | [optional] 
**short_description** | **str** |  | [optional] 
**citation** | [**Citation**](Citation.md) |  | [optional] 
**type** | **str** |  | [optional] 
**publication_date** | [**PublicationDateV30Rc2**](PublicationDateV30Rc2.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30Rc2**](ExternalIDsV30Rc2.md) |  | [optional] 
**url** | [**UrlV30Rc2**](UrlV30Rc2.md) |  | [optional] 
**contributors** | [**WorkContributorsV30Rc2**](WorkContributorsV30Rc2.md) |  | [optional] 
**language_code** | **str** |  | [optional] 
**country** | [**CountryV30Rc2**](CountryV30Rc2.md) |  | [optional] 
**visibility** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

